# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, Dict, List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from notifications_server_connector.models.source_type_id import SourceTypeId

class SendNotificationRequest(BaseModel):
    """
    SendNotificationRequest
    """
    source_type_id: SourceTypeId = Field(...)
    source_id: StrictInt = Field(...)
    portal_id: StrictInt = Field(...)
    portal_member_id: StrictInt = Field(...)
    title: StrictStr = Field(...)
    message: StrictStr = Field(...)
    is_anonymous: Optional[StrictBool] = False
    parent_id: Optional[StrictInt] = None
    parent_name: Optional[StrictStr] = None
    created_at: Optional[StrictInt] = None
    fcm_topic: Optional[StrictStr] = None
    notification_receivers: Optional[conlist(StrictInt)] = None
    args: Optional[Dict[str, Any]] = None
    extra_email_receivers: Optional[conlist(StrictStr)] = Field(default=None, description="Email addresses for non-portal members")
    subject_override: Optional[StrictStr] = Field(default=None, description="Inline subject template; takes precedence over portal override and Weblate")
    body_override: Optional[StrictStr] = Field(default=None, description="Inline body template; takes precedence over portal override and Weblate")
    __properties = ["source_type_id", "source_id", "portal_id", "portal_member_id", "title", "message", "is_anonymous", "parent_id", "parent_name", "created_at", "fcm_topic", "notification_receivers", "args", "extra_email_receivers", "subject_override", "body_override"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SendNotificationRequest:
        """Create an instance of SendNotificationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of source_type_id
        if self.source_type_id:
            _dict['source_type_id'] = self.source_type_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SendNotificationRequest:
        """Create an instance of SendNotificationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SendNotificationRequest.parse_obj(obj)

        _obj = SendNotificationRequest.parse_obj({
            "source_type_id": SourceTypeId.from_dict(obj.get("source_type_id")) if obj.get("source_type_id") is not None else None,
            "source_id": obj.get("source_id"),
            "portal_id": obj.get("portal_id"),
            "portal_member_id": obj.get("portal_member_id"),
            "title": obj.get("title"),
            "message": obj.get("message"),
            "is_anonymous": obj.get("is_anonymous") if obj.get("is_anonymous") is not None else False,
            "parent_id": obj.get("parent_id"),
            "parent_name": obj.get("parent_name"),
            "created_at": obj.get("created_at"),
            "fcm_topic": obj.get("fcm_topic"),
            "notification_receivers": obj.get("notification_receivers"),
            "args": obj.get("args"),
            "extra_email_receivers": obj.get("extra_email_receivers"),
            "subject_override": obj.get("subject_override"),
            "body_override": obj.get("body_override")
        })
        return _obj


